# Meowcorp

Meowcorp is a Python library that serves as an add-on to the aiogram library. It provides additional functionalities to help you create big and complex Telegram bots.

## Installation

To install Meowcorp, simply run:

```
pip install meowcorp
```

## Getting Started

To start a new project with Meowcorp, run:

```
meowcorp-admin startproject
```

This will create a new project with the necessary files and folders.

### Handlers

In the `branch` folder, you need to create handlers for messages. These handlers will be responsible for receiving and processing messages from users.

### Callback Handlers

In the `callback` folder, you need to create callback handlers. These handlers will be responsible for handling callbacks from inline keyboards.

### Keyboard Utilities

Meowcorp provides two utilities for creating keyboards: `create_keyboard` and `create_inline_keyboard`. These functions make it easy to create custom keyboards for your bot.

## Contributing

If you would like to contribute to Meowcorp, please fork the repository and submit a pull request. We welcome all contributions!

## License

Meowcorp is released under the MIT License. See [LICENSE](https://github.com/EluciferE/meowcorp/blob/main/LICENSE) for more information.